@@ -192,7 +192,6 @@ class DataMediator:
             smallSplit.merge(dataToAdd)
         # restore chained assignment warning
         pd.options.mode.chained_assignment = "warn"
-        # TODO: implement smote
 
     @property
     def featureCount(self, columnStratified=True):
@@ -203,22 +202,18 @@ class DataMediator:
         if hasattr(self, "train") and hasattr(self, "validation"):
             trainingShape = self.train.shape[1 if columnStratified else 0]
             testingShape = self.validation.shape[1 if columnStratified else 0]
-            return (
-                testingShape
-                if testingShape == trainingShape
-                else "unmatched feature count between training & testing!"
-            )
+            return testingShape if testingShape == trainingShape else False
         elif hasattr(self, "experimental") and hasattr(self, "control"):
             experimentalShape = self.experimental.shape[1 if columnStratified else 0]
             controlShape = self.control.shape[1 if columnStratified else 0]
-            return (
-                controlShape
-                if controlShape == experimentalShape
-                else "unmatched feature count between cases & controls!"
-            )
+            return controlShape if controlShape == experimentalShape else False
         else:
             return self.dataframe.shape[1 if columnStratified else 0]
 
+    @property
+    def sharedFeatureColumns(self):
+        return self.experimental.columns.intersection(self.control.columns)
+
     def resample(self, keepFilters=False) -> None:
         """
         Reinitialize experimental & control data; redo dataset balancing.
