@@ -113,37 +113,36 @@ class NeptuneExperimentTracker(ExperimentTracker):
         self,
         path: str,
         valueMap: dict,
+        projectLevel=False,
         **kwargs,
     ):
+        loggable = self.project if projectLevel else self.tracker
+
         for (key, value) in valueMap.items():
             if isinstance(value, Figure):
                 fileHandle = BytesIO()
                 value.savefig(fileHandle, format="svg")
-                self.tracker[f"{path}/{key}"].upload(
+                loggable[f"{path}/{key}"].upload(
                     File.from_stream(fileHandle, extension="svg")
                 )
-                self.tracker[f"{path}/{key} preview"].upload(File.as_image(value))
+                loggable[f"{path}/{key} preview"].upload(File.as_image(value))
             elif isinstance(value, DataFrame):
                 tableStream = BytesIO()
-                # tempFileName = (
-                #     os.path.join(self.tempDir, key + str(random.getrandbits(32)))
-                #     + ".csv"
-                # )
                 value.to_csv(tableStream, header=True, index=True)
-                self.tracker[f"{path}/{key}"].upload(
+                loggable[f"{path}/{key}"].upload(
                     File.from_stream(tableStream, extension="csv")
                     # tempFileName
                 )
             elif key == "model":
-                self.tracker[f"{path}/{key}"].upload(
+                loggable[f"{path}/{key}"].upload(
                     File.from_stream(BytesIO(value), extension="pkl")
                 )
             elif isinstance(value, bytes):
-                self.tracker[f"{path}/{key}"].upload(
+                loggable[f"{path}/{key}"].upload(
                     File.from_stream(BytesIO(value), extension="bin")
                 )
             else:
-                self.tracker[f"{path}/{key}"] = value
+                loggable[f"{path}/{key}"] = value
 
     def addTags(self, tags: List):
         self.tracker["sys/tags"].add(tags)
